@@ -1,16 +1,16 @@
 use crate::events::MountEvent;
-use crate::Callback;
+use crate::Listener;
 use crate::{
     dom::Dispatch,
     html,
-    html::attributes::{AttributeValue, Special},
-    Attribute,
+    html::attributes::{AttributeValue, SegregatedAttributes, Special},
+    Attribute, Event,
 };
 use once_cell::sync::OnceCell;
 use std::{collections::HashMap, sync::Mutex};
 use wasm_bindgen::{closure::Closure, JsCast, JsValue};
 use web_sys::{
-    self, Element, Event, EventTarget, HtmlElement, HtmlInputElement,
+    self, Element, EventTarget, HtmlElement, HtmlInputElement,
     HtmlTextAreaElement, Node, Text,
 };
 
@@ -30,7 +30,7 @@ fn create_unique_identifier() -> u32 {
     *elem_unique_id
 }
 
-pub(crate) const DATA_SAURON_VDOM_ID: &str = "data-sauron-vdom-id";
+pub(crate) const DATA_VDOM_ID: &str = "data-vdom-id";
 
 /// Closures that we are holding on to to make sure that they don't get invalidated after a
 /// VirtualNode is dropped.
@@ -81,19 +81,13 @@ impl CreatedNode {
                 CreatedNode::without_closures(text_node.unchecked_into())
             }
             crate::Node::Element(element_node) => {
-                let created_element: CreatedNode = Self::create_element_node(
-                    program,
-                    element_node,
-                    focused_node,
-                )
-                .into();
-                created_element
+                Self::create_element_node(program, element_node, focused_node)
             }
         }
     }
 
     /// dispatch the mount event,
-    /// call the callback since browser don't allow asynchronous execution of
+    /// call the listener since browser don't allow asynchronous execution of
     /// dispatching custom events (non-native browser events)
     fn dispatch_mount_event<DSP, MSG>(
         program: &DSP,
@@ -106,14 +100,11 @@ impl CreatedNode {
         for att in velem.attrs.iter() {
             if *att.name() == "mount" {
                 for val in att.value().iter() {
-                    match val {
-                        AttributeValue::EventListener(cb) => {
-                            let msg = cb.emit(MountEvent {
-                                target_node: element.clone().unchecked_into(),
-                            });
-                            program.dispatch(msg);
-                        }
-                        _ => (),
+                    if let AttributeValue::EventListener(cb) = val {
+                        let msg = cb.emit(Event::from(MountEvent {
+                            target_node: element.clone().unchecked_into(),
+                        }));
+                        program.dispatch(msg);
                     }
                 }
             }
@@ -133,13 +124,13 @@ impl CreatedNode {
     {
         let document = crate::document();
 
-        let element = if let Some(ref namespace) = velem.namespace() {
+        let element = if let Some(namespace) = velem.namespace() {
             document
-                .create_element_ns(Some(namespace), &velem.tag())
+                .create_element_ns(Some(namespace), velem.tag())
                 .expect("Unable to create element")
         } else {
             document
-                .create_element(&velem.tag())
+                .create_element(velem.tag())
                 .expect("Unable to create element")
         };
 
@@ -237,7 +228,12 @@ impl CreatedNode {
         MSG: 'static,
         DSP: Clone + Dispatch<MSG> + 'static,
     {
-        let (callbacks, plain_values, styles, func_values) =
+        let SegregatedAttributes {
+            listeners,
+            plain_values,
+            styles,
+            function_calls,
+        } =
             html::attributes::partition_callbacks_from_plain_styles_and_func_calls(
                 attr,
             );
@@ -246,7 +242,7 @@ impl CreatedNode {
         if let Some(merged_plain_values) =
             html::attributes::merge_plain_attributes_values(&plain_values)
         {
-            if let Some(ref namespace) = attr.namespace() {
+            if let Some(namespace) = attr.namespace() {
                 // Warning NOTE: set_attribute_ns should only be called
                 // when you meant to use a namespace
                 // using this with None will error in the browser with:
@@ -326,22 +322,21 @@ impl CreatedNode {
 
         // do function calls such as set_inner_html
         if let Some(merged_func_values) =
-            html::attributes::merge_plain_attributes_values(&func_values)
+            html::attributes::merge_plain_attributes_values(&function_calls)
         {
-            match *attr.name() {
-                "inner_html" => element.set_inner_html(&merged_func_values),
-                _ => (),
+            if *attr.name() == "inner_html" {
+                element.set_inner_html(&merged_func_values);
             }
         }
 
-        // add callbacks using add_event_listener
-        for callback in callbacks {
+        // add listeners using add_event_listener
+        for listener in listeners {
             let unique_id = create_unique_identifier();
 
             // set the data-sauron_vdom-id this will be read later on
             // when it's time to remove this element and its closures and event listeners
             element
-                .set_attribute(DATA_SAURON_VDOM_ID, &unique_id.to_string())
+                .set_attribute(DATA_VDOM_ID, &unique_id.to_string())
                 .expect("Could not set attribute on element");
 
             closures.insert(unique_id, vec![]);
@@ -350,19 +345,18 @@ impl CreatedNode {
             let current_elm: &EventTarget =
                 element.dyn_ref().expect("unable to cast to event targe");
 
-            // a custom enter event which triggers the callback
+            // a custom enter event which triggers the listener
             // when the enter key is pressed
             if *event_str == "enter" {
                 let program_clone = program.clone();
-                let callback_clone = callback.clone();
+                let listener_clone = listener.clone();
                 let key_press_func: Closure<dyn FnMut(web_sys::Event)> =
                     Closure::wrap(Box::new(move |event: web_sys::Event| {
                         let ke: &web_sys::KeyboardEvent = event
                             .dyn_ref()
                             .expect("should be a keyboard event");
                         if ke.key() == "Enter" {
-                            let msg =
-                                callback_clone.emit(Into::<Event>::into(event));
+                            let msg = listener_clone.emit(Event::from(event));
                             program_clone.dispatch(msg);
                         }
                     }));
@@ -377,7 +371,7 @@ impl CreatedNode {
                 key_press_func.forget();
             } else {
                 let callback_wrapped: Closure<dyn FnMut(web_sys::Event)> =
-                    create_closure_wrap(program, &callback);
+                    create_closure_wrap(program, listener);
                 current_elm
                     .add_event_listener_with_callback(
                         event_str,
@@ -408,13 +402,10 @@ impl CreatedNode {
 
         element.remove_attribute(attr.name())?;
 
-        match *attr.name() {
-            "checked" => {
-                if let Some(input) = element.dyn_ref::<HtmlInputElement>() {
-                    input.set_checked(false);
-                }
+        if *attr.name() == "checked" {
+            if let Some(input) = element.dyn_ref::<HtmlInputElement>() {
+                input.set_checked(false);
             }
-            _ => (),
         }
         Ok(())
     }
@@ -423,19 +414,17 @@ impl CreatedNode {
 /// This wrap into a closure the function that is dispatched when the event is triggered.
 pub(crate) fn create_closure_wrap<DSP, MSG>(
     program: &DSP,
-    callback: &Callback<MSG>,
+    listener: &Listener<MSG>,
 ) -> Closure<dyn FnMut(web_sys::Event)>
 where
     MSG: 'static,
     DSP: Clone + Dispatch<MSG> + 'static,
 {
-    let callback_clone = callback.clone();
-    // TODO: use a weak pointer here
-    // let program_weak = Rc::downgrade(&program)
+    let listener_clone = listener.clone();
     let program_clone = program.clone();
 
     Closure::wrap(Box::new(move |event: web_sys::Event| {
-        let msg = callback_clone.emit(event);
+        let msg = listener_clone.emit(Event::from(event));
         program_clone.dispatch(msg);
     }))
 }
