@@ -2,7 +2,7 @@
 //!
 //! [0]: https://developer.mozilla.org/en-US/docs/Web/Events
 use crate::html::attributes::AttributeValue;
-use crate::{Attribute, Callback};
+use crate::{Attribute, Listener};
 use wasm_bindgen::JsCast;
 #[cfg(web_sys_unstable_apis)]
 pub use web_sys::ClipboardEvent;
@@ -42,13 +42,22 @@ impl From<web_sys::Event> for Event {
     }
 }
 
+impl From<web_sys::MouseEvent> for Event {
+    fn from(mouse_event: MouseEvent) -> Self {
+        let event: web_sys::Event = mouse_event
+            .dyn_into()
+            .expect("Unable to cast mouse event into event");
+        Event::from(event)
+    }
+}
+
 /// an event builder
 pub fn on<F, MSG>(event_name: &'static str, f: F) -> Attribute<MSG>
 where
     F: Fn(Event) -> MSG + 'static,
     MSG: 'static,
 {
-    mt_dom::attr(event_name, AttributeValue::EventListener(Callback::from(f)))
+    mt_dom::attr(event_name, AttributeValue::EventListener(Listener::from(f)))
 }
 
 /// on click event
