@@ -43,27 +43,24 @@ where
     pub fn new(app: APP, root_node: &Node) -> Self {
         let dom_updater: DomUpdater<MSG> =
             DomUpdater::new(app.view(), root_node);
-        let program = Program {
+        Program {
             app: Rc::new(RefCell::new(app)),
             dom_updater: Rc::new(RefCell::new(dom_updater)),
-        };
-        program
-    }
-
-    fn init_emit(&self) {
-        // call the init of the component
-        let cmds = self.app.borrow_mut().init(self.clone());
-        // then emit the cmds, so it starts executing initial calls such (ie: fetching data,
-        // listening to events (resize, hashchange)
-        cmds.emit(&self);
+        }
     }
 
     /// executed after the program has been mounted
     fn after_mounted(&self) {
+        // inject the style first
         for style in self.app.borrow().style() {
             Self::inject_style(&style);
         }
-        self.init_emit();
+
+        // call the init of the component
+        let cmds = self.app.borrow_mut().init();
+        // then emit the cmds, so it starts executing initial calls such (ie: fetching data,
+        // listening to events (resize, hashchange)
+        cmds.emit(self);
     }
 
     /// get the real DOM node where this app is mounted to.
@@ -203,7 +200,7 @@ where
             Closure::once(move || {
                 program_clone.dispatch_inner(msg);
             });
-        crate::request_animation_frame(&closure_raf);
+        crate::dom::util::request_animation_frame_for_closure(&closure_raf);
         closure_raf.forget();
     }
 
