@@ -5,7 +5,7 @@ use crate::Attribute;
 use crate::Event;
 pub use attribute_macros::*;
 pub use attribute_value::AttributeValue;
-pub use callback::Callback;
+pub use listener::Listener;
 pub use special::{key, replace, skip, Special};
 pub use style::Style;
 pub use value::Value;
@@ -13,7 +13,7 @@ pub use value::Value;
 #[macro_use]
 mod attribute_macros;
 mod attribute_value;
-mod callback;
+mod listener;
 mod special;
 mod style;
 mod value;
@@ -395,36 +395,48 @@ pub(crate) fn merge_styles_attributes_values<MSG>(
     }
 }
 
-/// returns (callbacks, plain_attribtues, function_calls)
+/// The Attributes partition into 4 different types
+pub struct SegregatedAttributes<'a, MSG> {
+    /// the listeners of the event listeners
+    pub listeners: Vec<&'a Listener<Event, MSG>>,
+    /// plain attribute values
+    pub plain_values: Vec<&'a AttributeValue<MSG>>,
+    /// style attribute values
+    pub styles: Vec<&'a AttributeValue<MSG>>,
+    /// function calls
+    pub function_calls: Vec<&'a AttributeValue<MSG>>,
+}
+
+/// returns (listeners, plain_attribtues, function_calls)
 #[doc(hidden)]
 pub(crate) fn partition_callbacks_from_plain_styles_and_func_calls<MSG>(
     attr: &Attribute<MSG>,
-) -> (
-    Vec<&Callback<Event, MSG>>,
-    Vec<&AttributeValue<MSG>>,
-    Vec<&AttributeValue<MSG>>,
-    Vec<&AttributeValue<MSG>>,
-) {
-    let mut callbacks = vec![];
+) -> SegregatedAttributes<MSG> {
+    let mut listeners = vec![];
     let mut plain_values = vec![];
     let mut styles = vec![];
-    let mut func_values = vec![];
+    let mut function_calls = vec![];
     for av in attr.value() {
         match av {
             AttributeValue::Simple(_plain) => {
                 plain_values.push(av);
             }
             AttributeValue::FunctionCall(_call) => {
-                func_values.push(av);
+                function_calls.push(av);
             }
             AttributeValue::Style(_) => {
                 styles.push(av);
             }
             AttributeValue::EventListener(cb) => {
-                callbacks.push(cb);
+                listeners.push(cb);
             }
             _ => (),
         }
     }
-    (callbacks, plain_values, styles, func_values)
+    SegregatedAttributes {
+        listeners,
+        plain_values,
+        styles,
+        function_calls,
+    }
 }
