@@ -1,5 +1,5 @@
 use crate::prelude::{Style, Value};
-use crate::Callback;
+use crate::Listener;
 use std::fmt::{self, Debug};
 
 /// Values of an attribute can be in these variants
@@ -11,7 +11,7 @@ pub enum AttributeValue<MSG> {
     /// style values
     Style(Vec<Style>),
     /// Event Listener
-    EventListener(Callback<MSG>),
+    EventListener(Listener<MSG>),
     /// no value
     Empty,
 }
@@ -94,7 +94,7 @@ impl<MSG> AttributeValue<MSG> {
     /// return the value if it is a Simple variant
     pub fn get_simple(&self) -> Option<&Value> {
         match self {
-            AttributeValue::Simple(v) => Some(&v),
+            AttributeValue::Simple(v) => Some(v),
             _ => None,
         }
     }
@@ -102,21 +102,18 @@ impl<MSG> AttributeValue<MSG> {
     /// return the function call argument value if it is a FunctionCall variant
     pub fn get_function_call_value(&self) -> Option<&Value> {
         match self {
-            AttributeValue::FunctionCall(v) => Some(&v),
+            AttributeValue::FunctionCall(v) => Some(v),
             _ => None,
         }
     }
 
     /// returns true if this attribute value is a style
     pub fn is_style(&self) -> bool {
-        match self {
-            AttributeValue::Style(_) => true,
-            _ => false,
-        }
+        matches!(self, AttributeValue::Style(_))
     }
 
     /// return the styles if the attribute value is a style
-    pub fn as_event_listener(&self) -> Option<&Callback<MSG>> {
+    pub fn as_event_listener(&self) -> Option<&Listener<MSG>> {
         match self {
             AttributeValue::EventListener(cb) => Some(cb),
             _ => None,
@@ -133,17 +130,11 @@ impl<MSG> AttributeValue<MSG> {
 
     /// return true if this is a function call
     pub fn is_function_call(&self) -> bool {
-        match self {
-            AttributeValue::FunctionCall(_) => true,
-            _ => false,
-        }
+        matches!(self, AttributeValue::FunctionCall(_))
     }
 
     /// returns true if this attribute value is empty
     pub fn is_empty(&self) -> bool {
-        match self {
-            AttributeValue::Empty => true,
-            _ => false,
-        }
+        matches!(self, AttributeValue::Empty)
     }
 }
